import 'package:flutter/material.dart';
import 'package:geideadesignframework/GeideaColors.dart';
import 'package:geideadesignframework/style_config.dart';

class GeideaBottomModal extends StatefulWidget {
  GeideaBottomModal({
    Key key,
    this.titleColor = Colors.black,
    this.closeColor = Colors.black,
    this.title,
    this.titleFontSize = 16.0,
  }) : super(key: key);
  final Color titleColor;
  final Color closeColor;
  final double  titleFontSize;
  final String title;

  @override
  _GeideaBottomModalState createState() => _GeideaBottomModalState();

  static void showModal(BuildContext context, {List<Widget> children}) {
    showModalBottomSheet(
        context: context,
        builder: (BuildContext context) {
          return ClipRRect(
              borderRadius: BorderRadius.only(
                  topLeft: Radius.circular(20.0),
                  topRight: Radius.circular(20.0)),
              child: Container(
                  color: Colors.white,
                  child: Column(children: [
                    Row(
                        // A Row widget
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        // Free space will be equally divided and will be placed between the children.
                        children: [
                          IconButton(
                              // A normal IconButton
                              icon: Icon(
                                Icons.close,
                                color: closeColor ??
                                    styleConfig.theme.primaryColor,
                              ),
                              onPressed: () {
                                Navigator.of(context).pop();
                              }),
                          Flexible(
                            // A Flexible widget that will make its child flexible
                            child: Text(
                              title, // A very long text
                              overflow: TextOverflow.ellipsis,
                              style: TextStyle(
                                  color: titleColor ??
                                      styleConfig.theme.primaryColor,
                                  fontFamily: styleConfig.fontFamily,
                                  fontSize: titleFontSize), // handles overflowing of text
                            ),
                          ),
                          Opacity(
                              // A Opacity widget
                              opacity: 0.0,
                              // setting opacity to zero will make its child invisible
                              child: IconButton(
                                icon: Icon(Icons.clear), // some random icon
                                onPressed:
                                    null, // making the IconButton disabled
                              )),
                        ]),
                    Column(
                      children: children == null ? <Widget>[] : children,
                    )
                  ])));
        });
  }
}

class _GeideaBottomModalState extends State<GeideaBottomModal> {
  @override
  Widget build(BuildContext context) {
    return Container();
  }
}
